==> jei-1.21.5-fabric-21.3.0.17-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/TippedArrowRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.common.util.RegistryUtil;
import net.minecraft.class_10302;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1842;
import net.minecraft.class_1844;
import net.minecraft.class_1856;
import net.minecraft.class_1860;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3955;
import net.minecraft.class_5321;
import net.minecraft.class_7710;
import net.minecraft.class_7924;
import net.minecraft.class_8786;
import java.util.List;

public final class TippedArrowRecipeMaker {

	public static List<class_8786<class_3955>> createRecipes(IJeiHelpers jeiHelpers) {
		IVanillaRecipeFactory vanillaRecipeFactory = jeiHelpers.getVanillaRecipeFactory();

		String group = "jei.tipped.arrow";
		class_1856 arrowIngredient = class_1856.method_8101(class_1802.field_8107);

		class_2378<class_1842> potionRegistry = RegistryUtil.getRegistry(class_7924.field_41215);
		return potionRegistry.method_42017()
			.map(potion -> {
				class_1799 input = class_1844.method_57400(class_1802.field_8150, potion);
				class_1799 output = class_1844.method_57400(class_1802.field_8087, potion);
				output.method_7939(8);

				class_1856 potionIngredient = class_1856.method_8101(input.method_7909());
				class_2960 potionLocation = potion.method_40237().method_29177();
				class_2960 id = class_2960.method_60655(ModIds.MINECRAFT_ID, "jei.tipped.arrow." + potionLocation.method_12836() + "." + potionLocation.method_12832());
				class_5321<class_1860<?>> resourceKey = class_5321.method_29179(class_7924.field_52178, id);
				class_10302 slotDisplay = new class_10302.class_10307(output);
				class_3955 recipe = vanillaRecipeFactory.createShapedRecipeBuilder(class_7710.field_40251, slotDisplay)
					.group(group)
					.define('a', arrowIngredient)
					.define('p', potionIngredient, new class_10302.class_10307(input))
					.pattern("aaa")
					.pattern("apa")
					.pattern("aaa")
					.build();
				return new class_8786<>(resourceKey, recipe);
			})
			.toList();
	}

	private TippedArrowRecipeMaker() {

	}
}

==> jei-1.21.11-fabric-27.3.0.10-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/TippedArrowRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.common.util.RegistryUtil;
import net.minecraft.class_10302;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1842;
import net.minecraft.class_1844;
import net.minecraft.class_1856;
import net.minecraft.class_1860;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3955;
import net.minecraft.class_5321;
import net.minecraft.class_7710;
import net.minecraft.class_7924;
import net.minecraft.class_8786;
import java.util.List;

public final class TippedArrowRecipeMaker {

	public static List<class_8786<class_3955>> createRecipes(IJeiHelpers jeiHelpers) {
		IVanillaRecipeFactory vanillaRecipeFactory = jeiHelpers.getVanillaRecipeFactory();

		String group = "jei.tipped.arrow";
		class_1856 arrowIngredient = class_1856.method_8101(class_1802.field_8107);

		class_2378<class_1842> potionRegistry = RegistryUtil.getRegistry(class_7924.field_41215);
		return potionRegistry.method_42017()
			.map(potion -> {
				class_1799 input = class_1844.method_57400(class_1802.field_8150, potion);
				class_1799 output = class_1844.method_57400(class_1802.field_8087, potion);
				output.method_7939(8);

				class_1856 potionIngredient = class_1856.method_8101(input.method_7909());
				class_2960 potionId = potion.method_40237().method_29177();
				class_2960 recipeId = class_2960.method_60655(ModIds.MINECRAFT_ID, "jei.tipped.arrow." + potionId.method_12836() + "." + potionId.method_12832());
				class_5321<class_1860<?>> resourceKey = class_5321.method_29179(class_7924.field_52178, recipeId);
				class_10302 slotDisplay = new class_10302.class_10307(output);
				class_3955 recipe = vanillaRecipeFactory.createShapedRecipeBuilder(class_7710.field_40251, slotDisplay)
					.group(group)
					.define('a', arrowIngredient)
					.define('p', potionIngredient, new class_10302.class_10307(input))
					.pattern("aaa")
					.pattern("apa")
					.pattern("aaa")
					.build();
				return new class_8786<>(resourceKey, recipe);
			})
			.toList();
	}

	private TippedArrowRecipeMaker() {

	}
}
